@@ -868,7 +868,7 @@ gint read_config(AppletConfig * config) {
                                                      NULL);
     if (config->scale_in_popup < 1 || config->scale_in_popup >6)
         config->scale_in_popup = 1;
-    /*Get VIEW_MODE Default COLLAPSED*/
+    /* Get VIEW_MODE Default COLLAPSED */
     config->view_mode = COLLAPSED_VIEW_MODE;
     config->view_mode = gconf_client_get_int(gconf_client,
                                        GCONF_KEY_VIEW_MODE,
@@ -877,14 +877,12 @@ gint read_config(AppletConfig * config) {
                 || config->mode > EXPANDED_VIEW_MODE)
                         config->view_mode = COLLAPSED_VIEW_MODE;
 
-    /* Get mod Default Digia*/
+    /* Get mod Default Digia */
     tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
                                               GCONF_KEY_MOD,
                                               &gerror);
-    fprintf(stderr,"qqqqqqqqqqqqqqqqqqqqqqqq %s\n", tmp);
     if (!tmp ||gerror) {
-        fprintf(stderr, "sssssssssssssssssssssssss \n");
         config->mod = g_strdup("Digia");
         if(gerror){
             g_error_free(gerror);
