@@ -12,16 +12,16 @@
  *	for default icon set (Glance)
  *
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
+ * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU weather-config.h General Public
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
@@ -71,6 +71,9 @@ gboolean browser_url(gchar *url);
 void reload_omw_plugin(void);
 GtkWidget *create_hildon_clutter_icon_animation(const char *icon_path, int icon_size, GSList **objects_list);
 GHashTable* parse_animation_file(const gchar *filename, const gchar *encoding);
+gchar* create_presets_image_path(gchar* image);
+void load_style(void);
+
 #if defined HILDONANIMATION
 GHashTable *clear_animation_hash(GHashTable *hash);
 #endif
